/*
** Module   : Common.cs
** Abstract : Utility functions for data type conversion in Functions/Operators.
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -------------------------------- Description --------------------------------
** 001 OM  20140313 Created initial version. Support for conversion to IKVM wrapper and
**                  bidirectional for date and datetime.
*/

/** In this version we are using some deprecated API. Disable the warnings for the moment. */
#pragma warning disable 0612

using System;

/**
 * Utility class for simplifying the syntax of datatype conversions in Functions/Operators.
 */
public class Common
{
    /**
     * The constructor is private. No instances of this class are allowed. All access is done
     * using the static methods.
     */
    private Common()
    {
    }

    /**
     * Convert a date to IKVM equivalent.
     * NOTE: Uses deprecated API and should be rewritten.
     *
     * @params d
     *         The date to be converted.
     *
     * @returns a java.sql.Date IKVM object that holds the respective date.
     */
    public static java.sql.Date toDate(DateTime d)
    {
        return new java.sql.Date(d.Year, d.Month, d.Day);
    }

    /**
     * Convert a date/time to IKVM equivalent.
     * NOTE: Uses deprecated API and should be rewritten.
     *
     * @params t
     *         The date/time to be converted.
     *
     * @returns a java.sql.Timestamp IKVM object that holds the respective date/time.
     */
    public static java.sql.Timestamp toTimestamp(DateTime t)
    {
        return new java.sql.Timestamp(t.Year, t.Month, t.Day,
               t.Hour, t.Minute, t.Second, t.Millisecond * 1000000);
    }

    /**
     * Convert a IKVM date to CLR equivalent.
     * NOTE: Uses deprecated API and should be rewritten.
     *
     * @params d
     *         The date to be converted.
     *
     * @returns a CLR object that holds the respective date.
     */
    public static DateTime fromDate(java.sql.Date d)
    {
        return new DateTime(d.getYear(), d.getMonth(), d.getDate());
    }

    /**
     * Convert a IKVM date/time to CLR equivalent.
     * NOTE: Uses deprecated API and should be rewritten.
     *
     * @params t
     *         The date/time to be converted.
     *
     * @returns a CLR object that holds the respective date/time.
     */
    public static DateTime fromTimestamp(java.sql.Timestamp t)
    {
        return new DateTime(t.getYear(), t.getMonth(), t.getDate(),
                t.getHours(), t.getMinutes(), t.getSeconds(), t.getNanos() / 1000000);
    }

    /**
     * Convert a 32 bit integer to IKVM equivalent.
     *
     * @params value
     *         The value to be converted.
     *
     * @returns a java.lang.Integer IKVM object that holds the respective int number.
     */
    public static java.lang.Integer toInteger(Int32 value)
    {
        return java.lang.Integer.valueOf(value);
    }

    /**
     * Convert a 64 bit integer to IKVM equivalent.
     *
     * @params value
     *         The value to be converted.
     *
     * @returns a java.lang.Long IKVM object that holds the respective long number.
     */
    public static java.lang.Long toLong(Int64 value)
    {
        return java.lang.Long.valueOf(value);
    }

    /**
     * Convert a boolean value to IKVM equivalent.
     *
     * @params value
     *         The value to be converted.
     *
     * @returns a java.lang.Boolean IKVM object that holds the respective logical value.
     */
    public static java.lang.Boolean toBoolean(Boolean value)
    {
        return java.lang.Boolean.valueOf(value);
    }

    /**
     * Convert a decimal number to IKVM equivalent.
     *
     * @params value
     *         The value to be converted.
     *
     * @returns a java.math.BigDecimal IKVM object that holds the respective decimal number.
     */
    public static java.math.BigDecimal toBigDecimal(Double value)
    {
        return java.math.BigDecimal.valueOf(value);
    }
}
